==> gossiplog-0.11.0.tgz: package/lib/idb/index.js <==
import { toString } from "uint8arrays";
import { Mode } from "@canvas-js/okra";
import { Tree as MemoryTree } from "@canvas-js/okra-memory";
import { ModelDB } from "@canvas-js/modeldb-idb";
import { AbstractGossipLog } from "../AbstractGossipLog.js";
import { MerkleIndex } from "../MerkleIndex.js";
export class GossipLog extends AbstractGossipLog {
    static async open(init, options = {}) {
        const db = await ModelDB.initialize({
            name: `canvas/v1/${init.topic}`,
            models: { ...init.schema, ...AbstractGossipLog.schema },
            version: options.version,
        });
        const messageCount = await db.count("$messages");
        const merkleIndex = new MerkleIndex(db);
        const start = performance.now();
        const tree = await MemoryTree.fromEntries({ mode: Mode.Index }, merkleIndex.entries());
        const root = await tree.read((txn) => txn.getRoot());
        const delta = performance.now() - start;
        const gossipLog = new GossipLog(db, tree, init);
        gossipLog.log(`built in-memory merkle tree (root %d:%s, %d entries, %dms)`, root.level, toString(root.hash, "hex"), messageCount, Math.round(delta));
        return gossipLog;
    }
    constructor(db, tree, init) {
        super(init);
        Object.defineProperty(this, "db", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: db
        });
        Object.defineProperty(this, "tree", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: tree
        });
    }
}

==> gossiplog-0.12.3.tgz: package/lib/idb/index.js <==
import { toString } from "uint8arrays";
import { Mode } from "@canvas-js/okra";
import { Tree as MemoryTree } from "@canvas-js/okra-memory";
import { ModelDB } from "@canvas-js/modeldb-idb";
import { AbstractGossipLog } from "../AbstractGossipLog.js";
import { MerkleIndex } from "../MerkleIndex.js";
export class GossipLog extends AbstractGossipLog {
    static async open({ name, version, ...init }) {
        const db = await ModelDB.initialize({
            name: name ?? `canvas/v1/${init.topic}`,
            models: { ...init.schema, ...AbstractGossipLog.schema },
            version: version ?? 1,
        });
        const messageCount = await db.count("$messages");
        const merkleIndex = new MerkleIndex(db);
        const start = performance.now();
        const tree = await MemoryTree.fromEntries({ mode: Mode.Index }, merkleIndex.entries());
        const root = await tree.read((txn) => txn.getRoot());
        const delta = performance.now() - start;
        const gossipLog = new GossipLog(db, tree, init);
        gossipLog.log(`built in-memory merkle tree (root %d:%s, %d entries, %dms)`, root.level, toString(root.hash, "hex"), messageCount, Math.round(delta));
        return gossipLog;
    }
    constructor(db, tree, init) {
        super(init);
        Object.defineProperty(this, "db", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: db
        });
        Object.defineProperty(this, "tree", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: tree
        });
    }
}
